Recherche du seuil — Documentation audiometry_trainer 0.1.16

# Recherche du seuil

Le marqueur `S` dans la fenêtre de l’audiogramme indique la niveau courant du stimulus. Vous pouvez utiliser les flèches haut/bas de votre clavier pour changer le niveau du stimulus et les flèches droit/gauche pour changer sa fréquence. Vous pouvez présenter le stimulus au sujet virtuel en appuyant sur la barre espace (le `Témoin du stimulus` en bas s’allumera). Si le sujet virtuel a entendu le stimulus le `Témoin de réponse` sur la gauche s’allumera. Vous pouvez aussi utiliser le bouton `Play stimulus`, mais utiliser le clavier est généralement plus pratique.

Dans le panneau de gauche il y a des boutons pour marquer le niveau courant comme le seuil, marquer qu’il n’y a pas de réponse au niveau le plus haut possible (`Pas de réponse`) ou signaler un dilemme de masquage. Les raccourcis de clavier pour ces trois actions sont `T` pour marquer le seuil, `N` pour « pas de réponse », et `X` pour dilemme de masquage. En appuyant sur la touche `Suppr` ou sur la touche `D` vous pouvez supprimer la réponse qui est a présent enregistré.

`audiometry_trainer` tient le compte des réponses ascendantes pour vous assister dans la détermination du seuil selon la procédure Hugson-Westlake. Si vous ne souhaitez pas afficher ces comptes décochez la case `Afficher le compte des réponses`.

Si la case `Afficher l'oreille qui répond` est cochée le témoin de réponse sera rouge si la réponse origine de l’oreille droite, bleu si la réponse origine de l’oreille gauche, et blanc si les deux oreilles répondent au ton. Cela est utile pour illustrer le transfert crânien. Cela peut aussi simuler la situation dans laquelle l’audiologiste demande au sujet s’il entend le son dans son oreille droite ou gauche pour s’assurer, par exemple, que le masquage assourdisse efficacement l’oreille non testée. Ce dernier emploi ne devrait être pas abusé quand on est en train d’apprendre l’audiométrie clinique car, tandis que `audiometry_trainer` vous indiquera toujours la bonne réponse concernant l’oreille qui entend le son, dans la vraie vie les sujets ne sont pas toujours aussi fiable, donc vous ne devriez pas compter sur cela.

Le bouton `Rech. seuil automatique` exécute une recherche automatique du seuil avec la procédure Hughson-Westlake pour toutes les fréquences en utilisant le transducteur courant pour le canal 1. Cette recherche automatique du seuil est disponible uniquement pour la mesure des seuils non masqués. Cette fonctionnalité a été ajouté parce que l’aspect le plus intéressant de l’audiométrie est la mesure des seuils masqués (s’ils sont nécessaires), donc en utilisant la recherche automatique on peut vite obtenir les seuils non-masqués pour ensuite déterminer si le masquage est nécessaire et mesurer les seuils masqués le cas échéant.

Les cases `Afficher les seuils estimés` peuvent être cochées/décochées pour afficher/cacher les seuils qui ont été mesurés. Par défaut tous les seuils mesurés sont affichés sur l’audiogramme, mais parfois cela génère de l’encombrement (par ex. lorsque les seuils masqués sont obtenus après les seuils non-masqués) et il peut s’avérer utile de cacher certains des seuils mesurés.

Vous pouvez cocher les cases `Afficher les vrais seuils` en bas du panneau gauche pour comparer les seuils que vous avez mesuré avec les « vrais » seuils attendus. Les patients virtuels sont modélisés à partir de courbes psychométriques (voir la section Sujet virtuel) et les « vrai » seuils sont calculés à travers une méthode de Monte-Carlo (voir la section Générer des fichiers de cas), par conséquent, on ne doit pas s’attendre que le seuils mesurés et le seuils attendus soit parfaitement égal, mais il devraient être généralement très proches. Les « vrais » seuils sont le seuils médians obtenus sur un grand nombre de simulations ; des intervalles de confiance de 95% pour ces seuils peuvent être affichés en cochant les cases `CI`.